@@ -1,22 +1,23 @@
-;;; Miscellaneous functions for VM
-;;; Copyright (C) 1989-2001 Kyle E. Jones
-;;;
-;;; This program is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 1, or (at your option)
-;;; any later version.
-;;;
-;;; This program is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-;;(provide 'vm-misc)
+;;; vm-misc.el --- Miscellaneous functions for VM
+;;
+;; Copyright (C) 1989-2001 Kyle E. Jones
+;; Copyright (C) 2003-2006 Robert Widhopf-Fenk
+;;
+;; This program is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2 of the License, or
+;; (at your option) any later version.
+;;
+;; This program is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;;
+;; You should have received a copy of the GNU General Public License along
+;; with this program; if not, write to the Free Software Foundation, Inc.,
+;; 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
+;;; Code:
 (defun vm-delete-non-matching-strings (regexp list &optional destructively)
   "Delete strings matching REGEXP from LIST.
 Optional third arg non-nil means to destructively alter LIST, instead of
@@ -37,6 +38,13 @@ The new version of the list, minus the deleted strings, is returned."
     list ))
 
 (defun vm-parse (string regexp &optional matchn matches)
+  "Returns list of string by splitting STRING with REGEXP matches.
+REGEXP must match one item and MATCHN can be used to select a match
+group (default is 1).  MATCHES is the number of time the match is
+applied (default until it does not match anymore).
+
+This function is similar to a spring-split, but a bit more complex
+and flexible."
   (or matchn (setq matchn 1))
   (let (list tem)
     (store-match-data nil)
@@ -104,9 +112,20 @@ The new version of the list, minus the deleted strings, is returned."
 	     (if (and (null (string-match "^[\t\f\n\r ]+$" s))
 		      (not (string= s "")))
 		 (setq list (cons s list)))
-	     (nreverse list)) ; jwz: fixed order
+             (mapcar 'vmrf-fix-quoted-address (reverse list)))
 	(and work-buffer (kill-buffer work-buffer)))))))
 
+(defun vmrf-fix-quoted-address (a)
+  "RF: evetually there are qp-encoded addresses not quoted by \" and thus we
+  need to add quotes or leave them undecoded."
+  (let ((da (vm-decode-mime-encoded-words-in-string a)))
+    (if (string= da a)
+        a
+      (if (or (string-match "^\\s-*\\([^\"']*,[^\"']*\\)\\b\\s-*\\(<.*\\)" da)
+              (string-match "^\\s-*\"'\\([^\"']+\\)'\"\\(.*\\)" da))
+          (concat "\"" (match-string 1 da) "\" " (match-string 2 da))
+        da))))
+          
 (defun vm-parse-structured-header (string &optional sepchar keep-quotes)
   (if (null string)
       ()
@@ -618,6 +637,8 @@ If HACK-ADDRESSES is t, then the strings are considered to be mail addresses,
     file ))
 
 (defun vm-make-tempfile-name (&optional filename-suffix proposed-filename)
+  (if (stringp proposed-filename)
+      (setq proposed-filename (file-name-nondirectory proposed-filename)))
   (let (filename)
     (cond ((and (stringp proposed-filename)
 		(not (file-exists-p
@@ -635,8 +656,8 @@ If HACK-ADDRESSES is t, then the strings are considered to be mail addresses,
 					vm-tempfile-counter
 					proposed-filename)
 				vm-temp-file-directory))
-		     vm-tempfile-counter (1+ vm-tempfile-counter))
-	       done (not (file-exists-p filename)))))
+		     vm-tempfile-counter (1+ vm-tempfile-counter)
+                     done (not (file-exists-p filename))))))
 	  (t
 	   (let ((done nil))
 	     (while (not done)
@@ -834,8 +855,8 @@ If HACK-ADDRESSES is t, then the strings are considered to be mail addresses,
        (widen)
        (or (markerp end) (setq end (vm-marker end)))
        (goto-char start)
-       (while (not done)
-	 (re-search-forward "$" end t)
+       (while (and (not done) (re-search-forward "[ \t]*$" end t))
+         (replace-match "")
 	 (if (>= (current-column) len)
 	     ;; ignore errors
 	     (condition-case nil
@@ -882,7 +903,7 @@ If HACK-ADDRESSES is t, then the strings are considered to be mail addresses,
 (defvar enable-multibyte-characters)
 (defvar buffer-display-table)
 (defun vm-fsfemacs-nonmule-display-8bit-chars ()
-  (cond ((and vm-fsfemacs-p 
+  (cond ((and vm-fsfemacs-p
 	      (or (not vm-fsfemacs-mule-p)
 		  (and (boundp 'enable-multibyte-characters)
 		       (not enable-multibyte-characters))))
@@ -935,4 +956,28 @@ If HACK-ADDRESSES is t, then the strings are considered to be mail addresses,
 	(scroll-bar-mode nil)
 	(setq vm-fsfemacs-cached-scroll-bar-width size))))
 
+(defvar vm-disable-modes-ignore nil
+  "List of modes ignored by `vm-disable-modes'.
+Any mode causing an error while trying to disable it will be added to this
+list.  It still will try to diable it, but no error messages are generated
+anymore for it.")
+
+(defun vm-disable-modes (&optional modes)
+  "Disable the given minor modes.
+If MODES is nil the take the modes from the variable 
+`vm-disable-modes-before-encoding'."
+  (let (m)
+    (while modes
+      (setq m (car modes) modes (cdr modes))
+      (condition-case errmsg
+          (if (functionp m)
+              (funcall m -1))
+	(error 
+	 (when (not (member m vm-disable-modes-ignore))
+	   (message "Could not disable mode `%S': %S" m errmsg)
+	   (setq vm-disable-modes-ignore (cons m vm-disable-modes-ignore)))
+	 nil)))))
+
 (provide 'vm-misc)
+
+;;; vm-misc.el ends here
