@@ -6,7 +6,7 @@
 ;; Status:      Tested with XEmacs 21.4.19 & VM 7.19
 ;; Keywords:    VM helpers
 ;; X-URL:       http://www.robf.de/Hacking/elisp
-;; Version:     $Id: vm-pgg.el,v 1.1 2008/04/09 21:01:52 fenk Exp $
+;; Version:     $Id: vm-pgg.el,v 1.2 2008/07/23 07:23:15 stephent Exp $
 
 ;;
 ;; This code is free software; you can redistribute it and/or modify
@@ -886,6 +886,7 @@ cleanup here after verification and decoding took place."
            ;; after decode the state of vm-mime-decoded is 'buttons
            nil)
           ((not (and (= (length part-list) 2)
+		     signature
                      ;; TODO: check version and protocol here?
                      (vm-mime-types-match (car (vm-mm-layout-type signature))
                                           "application/pgp-signature")))
@@ -897,9 +898,10 @@ cleanup here after verification and decoding took place."
              (insert
               (format
                "******* unknown signature type %s *******\n"
-               (car (vm-mm-layout-type signature))))
+               (car (and signature (vm-mm-layout-type signature)))))
              (setq end (point))
-             (vm-decode-mime-layout signature)
+	     (when signature
+	       (vm-decode-mime-layout signature))
              (put-text-property start end 'face 'vm-pgg-unknown-signature-type))
            t)
           (t 
